/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache License Version 2.0.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2016-Present Datadog, Inc.
 */

package com.datadog.tools.unit

import com.datadog.android.trace.TracingHeaderType
import com.facebook.react.bridge.JavaOnlyArray
import com.facebook.react.bridge.JavaOnlyMap
import com.facebook.react.bridge.ReadableArray
import com.facebook.react.bridge.ReadableMap

fun Map<*, *>.toReadableMap(): ReadableMap {
    val keysAndValues = mutableListOf<Any?>()

    entries.forEach {
        keysAndValues.add(it.key)
        keysAndValues.add(it.value)
    }

    // this FB implementation is not backed by Android-specific .so library, so ok for unit tests
    return JavaOnlyMap.of(*keysAndValues.toTypedArray())
}

fun Map<String, Set<TracingHeaderType>>.toFirstPartyHostsReadableArray(): ReadableArray {
    val list = mutableListOf<Any>()

    entries.forEach {
        list.add(
            mapOf(
                "match" to it.key,
                "propagatorTypes" to it.value.map {
                        tracingHeaderType ->
                    tracingHeaderType.toString().lowercase()
                }.toReadableArray()
            ).toReadableMap()
        )
    }

    return JavaOnlyArray.from(list)
}

fun List<*>.toReadableArray(): ReadableArray {
    // this FB implementation is not backed by Android-specific .so library, so ok for unit tests
    return JavaOnlyArray.from(this)
}

fun Set<*>.toReadableArray(): ReadableArray {
    // this FB implementation is not backed by Android-specific .so library, so ok for unit tests
    return JavaOnlyArray.from(this.toList())
}

fun ReadableMap.keys(): List<String> {
    val keys = mutableListOf<String>()
    val iterator = this.keySetIterator()
    while (iterator.hasNextKey()) {
        keys.add(iterator.nextKey())
    }
    return keys
}
